@@ -2,6 +2,10 @@
 
 require("core-js/modules/es.typed-array.set.js");
 
+require("core-js/modules/web.atob.js");
+
+require("core-js/modules/web.btoa.js");
+
 require("core-js/modules/web.dom-exception.constructor.js");
 
 require("core-js/modules/web.dom-exception.stack.js");
